function varargout = signal_conditioner(varargin)
% SIGNAL_CONDITIONER MATLAB code for signal_conditioner.fig
%      SIGNAL_CONDITIONER, by itself, creates a new SIGNAL_CONDITIONER or raises the existing
%      singleton*.
%      SIGNAL CONDITIONER tool was developed for demonstration of
%      amplifiers and filters (1st order Bessel filter is used)
%      The routine should be used together with WAVEFORM_GEN tool. However,
%      it might work for any signal stored in the workspace as "waveform"
%      *************************************************************************
%      INPUT DATA 
%      waveform     -> the routine requires an exhisting waveform, if no
%                   waveform is available an error message is shown
%      *************************************************************************
%      OUTPUT DATA
%      waveform_amplif -> is the waveform generated with WAVEFORM_GEN tool
%                       multiplied by a given factor. This factor is selected on the GUI
%                       (Guided User Interface) panel
%      waveform_original -> is the waveform generated with WAVEFORM_GEN tool
%                       The original signal is stored in the workspace in
%                       as a backup 
%      waveform          -> the conditioned signal is stored in the
%                       variable waveform. This if one is observing this 
%                       signal in the OSCILLOSCOPE tool, it will be
%                       updated if any signal conditioning is applied
%      *************************************************************************
%      HOW TO USE THE GUI TOOL?
%      1) Open the file "signal_conditioner.m" in the matlab editor
%      2) Press run (or F5) to start the GUI
%      3) Select an operation mode for the Filter and/or the amplifier and a
%      gain and/or cutoff frequency
%      4) Press Apply to amplify/filter the signal. OBS: the
%      conditioning is applied ONLY WHEN the APPLY button is pressed. If
%      conditioning parameters are modified, the user must press remove and
%      then press apply again.
%      *************************************************************************
%      H = SIGNAL_CONDITIONER returns the handle to a new SIGNAL_CONDITIONER or the handle to
%      the existing singleton*.
%
%      SIGNAL_CONDITIONER('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in SIGNAL_CONDITIONER.M with the given input arguments.
%
%      SIGNAL_CONDITIONER('Property','Value',...) creates a new SIGNAL_CONDITIONER or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before signal_conditioner_OpeningFcn gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to signal_conditioner_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help signal_conditioner
% Created by I. B. de Paula, PUC-Rio 2017
% Last Modified by GUIDE v2.5 17-Aug-2017 09:04:06

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @signal_conditioner_OpeningFcn, ...
                   'gui_OutputFcn',  @signal_conditioner_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT


% --- Executes just before signal_conditioner is made visible.
function signal_conditioner_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to signal_conditioner (see VARARGIN)

% Choose default command line output for signal_conditioner
handles.output = hObject;
tmp=imread('knob.tif');
imshow(tmp,'parent',handles.axes1);
imshow(tmp,'parent',handles.axes2);
imshow(tmp,'parent',handles.axes7);
imshow(tmp,'parent',handles.axes6);

% Update handles structure
guidata(hObject, handles);

% UIWAIT makes signal_conditioner wait for user response (see UIRESUME)
% uiwait(handles.figure1);


% --- Outputs from this function are returned to the command line.
function varargout = signal_conditioner_OutputFcn(hObject, eventdata, handles) 
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure
varargout{1} = handles.output;


% --- Executes during object creation, after setting all properties.
function filt_mode_CreateFcn(hObject, eventdata, handles)
% hObject    handle to filt_mode (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


% --- Executes during object creation, after setting all properties.
function amp_mode_CreateFcn(hObject, eventdata, handles)
% hObject    handle to amp_mode (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end


%***********************************************************************
%                          AMPLIFIER FUNCTIONS
%***********************************************************************



% --- Executes on button press in amp_on.
function amp_on_Callback(hObject, eventdata, handles)
% hObject    handle to amp_on (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
amp_on=get(handles.amp_on,'Value');
vector_gain=[1 2 3 4 5 6 7 8 9];
vector_multip=[1 10 100 1000];

unity_gain=[ get(handles.gain1,'Value') get(handles.gain2,'Value') get(handles.gain3,'Value') ...
            get(handles.gain4,'Value') get(handles.gain5,'Value') get(handles.gain6,'Value') ...
            get(handles.gain7,'Value') get(handles.gain8,'Value') get(handles.gain9,'Value')];
        
multip_gain=[ get(handles.gx1,'Value') get(handles.gx10,'Value') get(handles.gx100,'Value') ...
            get(handles.gx1000,'Value')];
total_gain=sum(vector_gain.*unity_gain)*sum(multip_gain.*vector_multip);   
        
if amp_on==1
    set(handles.amp_on,'String','Remove');
    filt_on=get(handles.filt_on,'Value');
    
    if evalin('base','exist(''waveform'')')==0
        h2=msgbox('No signal available. Please generate a waveform using the tool "waveform_gen.m"');
    elseif evalin('base','exist(''waveform_original'')')==0
        time=evalin('base','time');
        signal=evalin('base','waveform');
        assignin('base','waveform_original',signal);
    elseif evalin('base','exist(''waveform_filt'')')==0
        time=evalin('base','time');
        signal=evalin('base','waveform_original');
    elseif filt_on==1
        time=evalin('base','time');
        signal=evalin('base','waveform_filt');
        disp('load waveform_filt')        
    else
        time=evalin('base','time');
        signal=evalin('base','waveform_original');
    end
    if evalin('base','exist(''waveform'')')~=0
        mean_sig=mean(signal)*floor(abs(get(handles.amp_mode,'Value')-1.7));
        gnd=sign(abs(get(handles.amp_mode,'Value')-2));
        signal=gnd*((signal-mean_sig)*total_gain+2e-3*randn([1,length(signal)]));
        ctrl=find(signal>9.5 | signal<-9.5);
        if isempty(ctrl)==0
            signal(ctrl)=sign(signal(ctrl))*9.5;
        end
        assignin('base','waveform',signal);
         if evalin('base','exist(''waveform_original'')')~=0 
            disp('saving original amplif')
            signal_original=evalin('base','waveform_original');
            mean_sig_original=mean(signal_original)*floor(abs(get(handles.amp_mode,'Value')-1.7));
            signal_ampl=gnd*((signal_original-mean_sig_original)*total_gain+2e-3*randn([1,length(signal)]));
            assignin('base','waveform_ampl',signal_ampl);
         else
             disp('saving amplif')
             assignin('base','waveform_ampl',signal);
         end
        
    end
else
    filt_on=get(handles.filt_on,'Value');
    if evalin('base','exist(''waveform_filt'')')==0
        signal=evalin('base','waveform_original');
        assignin('base','waveform',signal);
        disp('storing original')
    elseif filt_on==1
        signal_filt=evalin('base','waveform_filt');
        signal=evalin('base','waveform_original');
        amplif=max(signal_filt)/max(signal)
        if amplif<=1
            assignin('base','waveform',signal_filt);
            disp('storing filt signal')
        else
            assignin('base','waveform',signal_filt/total_gain);
            assignin('base','waveform_filt',signal_filt/total_gain);
            disp('storing corrected filt')
        end
    else
        signal=evalin('base','waveform_original');
        assignin('base','waveform',signal);      
    end
     set(handles.amp_on,'String','Apply')
 %   signal=evalin('base','waveform_original');
 %   assignin('base','waveform',signal);
end
% Hint: get(hObject,'Value') returns toggle state of amp_on

   




% --- Executes on selection change in amp_mode.
function amp_mode_Callback(hObject, eventdata, handles)
% hObject    handle to amp_mode (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = cellstr(get(hObject,'String')) returns amp_mode contents as cell array
%        contents{get(hObject,'Value')} returns selected item from amp_mode



% --- Executes on button press in gain1.
function gain1_Callback(hObject, eventdata, handles)
% hObject    handle to gain1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain1,'Value');
if gain_unity==1
    set(handles.gain2,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain8,'Value',0);
    set(handles.gain9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gain1


% --- Executes on button press in gain2.
function gain2_Callback(hObject, eventdata, handles)
% hObject    handle to gain2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain2,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain8,'Value',0);
    set(handles.gain9,'Value',0);
end

% Hint: get(hObject,'Value') returns toggle state of gain2


% --- Executes on button press in gain3.
function gain3_Callback(hObject, eventdata, handles)
% hObject    handle to gain3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain3,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain2,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain8,'Value',0);
    set(handles.gain9,'Value',0);
end

% Hint: get(hObject,'Value') returns toggle state of gain3


% --- Executes on button press in gain4.
function gain4_Callback(hObject, eventdata, handles)
% hObject    handle to gain4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain4,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain2,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain8,'Value',0);
    set(handles.gain9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gain4

% --- Executes on button press in gain5.
function gain5_Callback(hObject, eventdata, handles)
% hObject    handle to gain5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain5,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain2,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain8,'Value',0);
    set(handles.gain9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gain5


% --- Executes on button press in gain6.
function gain6_Callback(hObject, eventdata, handles)
% hObject    handle to gain6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain6,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain2,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain8,'Value',0);
    set(handles.gain9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gain6


% --- Executes on button press in gain7.
function gain7_Callback(hObject, eventdata, handles)
% hObject    handle to gain7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain7,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain2,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain8,'Value',0);
    set(handles.gain9,'Value',0);
end

% Hint: get(hObject,'Value') returns toggle state of gain7


% --- Executes on button press in gain8.
function gain8_Callback(hObject, eventdata, handles)
% hObject    handle to gain8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain8,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain2,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gain8


% --- Executes on button press in gain9.
function gain9_Callback(hObject, eventdata, handles)
% hObject    handle to gain9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_unity=get(handles.gain9,'Value');
if gain_unity==1
    set(handles.gain1,'Value',0);
    set(handles.gain2,'Value',0);
    set(handles.gain3,'Value',0);
    set(handles.gain4,'Value',0);
    set(handles.gain5,'Value',0);
    set(handles.gain6,'Value',0);
    set(handles.gain7,'Value',0);
    set(handles.gain8,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gain9


% --- Executes on button press in gx1.
function gx1_Callback(hObject, eventdata, handles)
% hObject    handle to gx1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_multip=get(handles.gx1,'Value');
if gain_multip==1
    set(handles.gx10,'Value',0);
    set(handles.gx100,'Value',0);
    set(handles.gx1000,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gx1


% --- Executes on button press in gx10.
function gx10_Callback(hObject, eventdata, handles)
% hObject    handle to gx10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_multip=get(handles.gx10,'Value');
if gain_multip==1
    set(handles.gx1,'Value',0);
    set(handles.gx100,'Value',0);
    set(handles.gx1000,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gx10


% --- Executes on button press in gx100.
function gx100_Callback(hObject, eventdata, handles)
% hObject    handle to gx100 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_multip=get(handles.gx100,'Value');
if gain_multip==1
    set(handles.gx1,'Value',0);
    set(handles.gx10,'Value',0);
    set(handles.gx1000,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gx100


% --- Executes on button press in gx1000.
function gx1000_Callback(hObject, eventdata, handles)
% hObject    handle to gx1000 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
gain_multip=get(handles.gx1000,'Value');
if gain_multip==1
    set(handles.gx1,'Value',0);
    set(handles.gx10,'Value',0);
    set(handles.gx100,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of gx1000


% --- Executes on button press in radiobutton17.




%***********************************************************************
%                         FILTER FUNCTIONS
%***********************************************************************



% --- Executes on button press in filt_on.
function filt_on_Callback(hObject, eventdata, handles)
% hObject    handle to filt_on (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hint: get(hObject,'Value') returns toggle state of filt_on

filt_on=get(handles.filt_on,'Value');

vector_cutoff=[1 2 3 4 5 6 7 8 9];
vector_multip=[1 10 100 1000];

unity_cutoff=[ get(handles.cut1,'Value') get(handles.cut2,'Value') get(handles.cut3,'Value') ...
    get(handles.cut4,'Value') get(handles.cut5,'Value') get(handles.cut6,'Value') ...
    get(handles.cut7,'Value') get(handles.cut8,'Value') get(handles.cut9,'Value')];

multip_cutoff=[ get(handles.xcut1,'Value') get(handles.xcut10,'Value') get(handles.xcut100,'Value') ...
    get(handles.xcut1000,'Value')];



if filt_on==1
    set(handles.filt_on,'String','Remove')
    amp_on=get(handles.amp_on,'Value');
    total_filt=sum(vector_cutoff.*unity_cutoff)*sum(multip_cutoff.*vector_multip);
    if evalin('base','exist(''waveform'')')==0
        h2=msgbox('No signal available. Please generate a waveform using the tool "waveform_gen.m"');
    else
        if evalin('base','exist(''waveform_original'')')==0
            time=evalin('base','time');
            signal=evalin('base','waveform');
            assignin('base','waveform_original',signal);
            disp('option 1');
        elseif evalin('base','exist(''waveform_ampl'')')==0
            time=evalin('base','time');
            signal=evalin('base','waveform_original');
            disp('option 2')
        elseif amp_on==1
            time=evalin('base','time');
            signal=evalin('base','waveform_ampl');
            disp('load waveform_amplified')
            disp('option 3')
        else
            time=evalin('base','time');
            signal=evalin('base','waveform_original');
            disp('option 4')
        end
        dt=time(2)-time(1);
        df=1/max(time+dt); %base frequency
        freq=-(1/dt)/2:df:(1/dt)/2-df;
        %disp(['Length time= ' num2str(length(time))]);
        fft_signal=fftshift(fft(signal));
        filt_mode=get(handles.filt_mode,'Value');
        if filt_mode==1
            % low pass filter
            filt(length(freq)/2+1:length(freq))=1./(1+sqrt(-1)*abs(freq(length(freq)/2+1:length(freq)))/total_filt);
            filt(1:length(freq)/2)=conj(filt(end:-1:length(freq)/2+1));
            filt(length(freq/2))=1;
            %disp(['Length Filt= ' num2str(length(filt))]);
        else
            filt(length(freq)/2+1:length(freq))=(sqrt(-1)*abs(freq(length(freq)/2+1:length(freq)))/total_filt)./(1+sqrt(-1)*abs(freq(length(freq)/2+1:length(freq)))/total_filt);
            filt(1:length(freq)/2)=conj(filt(end:-1:length(freq)/2+1));
            filt(length(freq/2))=0;
            %disp(['Length Filt= ' num2str(length(filt))]);
        end
        signal_filt=real(ifft(fftshift(fft_signal.*filt)))+1.e-3*randn([1,length(signal)]);
        assignin('base','waveform',signal_filt);
        if evalin('base','exist(''waveform_original'')')~=0
            signal_original=evalin('base','waveform_original');
            fft_signal_original=fftshift(fft(signal_original));
            signal_filt_original=real(ifft(fftshift(fft_signal_original.*filt)))+1.e-3*randn([1,length(signal)]);
            assignin('base','waveform_filt',signal_filt_original);
            disp('saving filt_original')
        else
            assignin('base','waveform_filt',signal_filt);
            disp('saving filt')
        end
    end
else
    set(handles.filt_on,'String','Apply');
    amp_on=get(handles.amp_on,'Value');
    if evalin('base','exist(''waveform_ampl'')')==0
        signal=evalin('base','waveform_original');
        assignin('base','waveform',signal);
        disp('storing original')
    elseif amp_on==1
        if evalin('base','exist(''waveform_original'')')~=0
            signal=evalin('base','waveform_ampl');
            assignin('base','waveform',signal);
            disp('storing amplif')
        else
            signal=evalin('base','waveform_original');
            assignin('base','waveform',signal);
            disp('storing original')
        end
        
    else
        signal=evalin('base','waveform_original');
        assignin('base','waveform',signal);
        disp('storing original')
    end
    
end

% --- Executes on selection change in filt_mode.
function filt_mode_Callback(hObject, eventdata, handles)
% hObject    handle to filt_mode (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = cellstr(get(hObject,'String')) returns filt_mode contents as cell array
%        contents{get(hObject,'Value')} returns selected item from filt_mode





% --- Executes on button press in xcut1.
function xcut1_Callback(hObject, eventdata, handles)
% hObject    handle to xcut1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_multip=get(handles.xcut1,'Value');
if cutoff_multip==1
    set(handles.xcut10,'Value',0);
    set(handles.xcut100,'Value',0);
    set(handles.xcut1000,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of xcut1


% --- Executes on button press in xcut10.
function xcut10_Callback(hObject, eventdata, handles)
% hObject    handle to xcut10 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_multip=get(handles.xcut10,'Value');
if cutoff_multip==1
    set(handles.xcut1,'Value',0);
    set(handles.xcut100,'Value',0);
    set(handles.xcut1000,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of xcut10


% --- Executes on button press in xcut100.
function xcut100_Callback(hObject, eventdata, handles)
% hObject    handle to xcut100 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_multip=get(handles.xcut100,'Value');
if cutoff_multip==1
    set(handles.xcut1,'Value',0);
    set(handles.xcut10,'Value',0);
    set(handles.xcut1000,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of xcut100


% --- Executes on button press in xcut1000.
function xcut1000_Callback(hObject, eventdata, handles)
% hObject    handle to xcut1000 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_multip=get(handles.xcut1000,'Value');
if cutoff_multip==1
    set(handles.xcut1,'Value',0);
    set(handles.xcut10,'Value',0);
    set(handles.xcut100,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of xcut1000


% --- Executes on button press in cut1.
function cut1_Callback(hObject, eventdata, handles)
% hObject    handle to cut1 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut1,'Value');
if cutoff_unity==1
    set(handles.cut2,'Value',0);
    set(handles.cut3,'Value',0);
    set(handles.cut4,'Value',0);
    set(handles.cut5,'Value',0);
    set(handles.cut6,'Value',0);
    set(handles.cut7,'Value',0);
    set(handles.cut8,'Value',0);
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut1


% --- Executes on button press in cut2.
function cut2_Callback(hObject, eventdata, handles)
% hObject    handle to cut2 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut2,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut3,'Value',0);
    set(handles.cut4,'Value',0);
    set(handles.cut5,'Value',0);
    set(handles.cut6,'Value',0);
    set(handles.cut7,'Value',0);
    set(handles.cut8,'Value',0);
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut2


% --- Executes on button press in cut3.
function cut3_Callback(hObject, eventdata, handles)
% hObject    handle to cut3 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut3,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut2,'Value',0);
    
    set(handles.cut4,'Value',0);
    set(handles.cut5,'Value',0);
    set(handles.cut6,'Value',0);
    set(handles.cut7,'Value',0);
    set(handles.cut8,'Value',0);
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut3


% --- Executes on button press in cut4.
function cut4_Callback(hObject, eventdata, handles)
% hObject    handle to cut4 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut4,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut2,'Value',0);
    set(handles.cut3,'Value',0);
    
    set(handles.cut5,'Value',0);
    set(handles.cut6,'Value',0);
    set(handles.cut7,'Value',0);
    set(handles.cut8,'Value',0);
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut4



% --- Executes on button press in cut5.
function cut5_Callback(hObject, eventdata, handles)
% hObject    handle to cut5 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut5,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut2,'Value',0);
    set(handles.cut3,'Value',0);
    set(handles.cut4,'Value',0);
   
    set(handles.cut6,'Value',0);
    set(handles.cut7,'Value',0);
    set(handles.cut8,'Value',0);
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut5

% --- Executes on button press in cut6.
function cut6_Callback(hObject, eventdata, handles)
% hObject    handle to cut6 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut6,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut2,'Value',0);
    set(handles.cut3,'Value',0);
    set(handles.cut4,'Value',0);
    set(handles.cut5,'Value',0);
    
    set(handles.cut7,'Value',0);
    set(handles.cut8,'Value',0);
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut6


% --- Executes on button press in cut7.
function cut7_Callback(hObject, eventdata, handles)
% hObject    handle to cut7 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut7,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut2,'Value',0);
    set(handles.cut3,'Value',0);
    set(handles.cut4,'Value',0);
    set(handles.cut5,'Value',0);
    set(handles.cut6,'Value',0);
    
    set(handles.cut8,'Value',0);
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut7


% --- Executes on button press in cut8.
function cut8_Callback(hObject, eventdata, handles)
% hObject    handle to cut8 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut8,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut2,'Value',0);
    set(handles.cut3,'Value',0);
    set(handles.cut4,'Value',0);
    set(handles.cut5,'Value',0);
    set(handles.cut6,'Value',0);
    set(handles.cut7,'Value',0);
   
    set(handles.cut9,'Value',0);
end
% Hint: get(hObject,'Value') returns toggle state of cut8


% --- Executes on button press in cut9.
function cut9_Callback(hObject, eventdata, handles)
% hObject    handle to cut9 (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
cutoff_unity=get(handles.cut9,'Value');
if cutoff_unity==1
    set(handles.cut1,'Value',0);
    set(handles.cut2,'Value',0);
    set(handles.cut3,'Value',0);
    set(handles.cut4,'Value',0);
    set(handles.cut5,'Value',0);
    set(handles.cut6,'Value',0);
    set(handles.cut7,'Value',0);
    set(handles.cut8,'Value',0);
    
end
% Hint: get(hObject,'Value') returns toggle state of cut9
